Other methods of authentication, like cookie based authentication must be
used as a replacement. This can still be considered insecure if credentials are
submitted in clear text. TLS Encryption must be used when transmitting sensitive
information.